@@ -4,6 +4,7 @@ use crate::auxiliary::align;
 use crate::traits::{AsPages, Protectable};
 
 use std::convert::TryInto;
+use std::intrinsics::{likely, unlikely};
 use std::io::Error;
 use std::marker::PhantomData;
 use std::mem::{MaybeUninit, ManuallyDrop};
@@ -140,10 +141,12 @@ impl<'t> Pages<'t> {
 		self.0.as_ptr().cast::<T>()
 	}
 
+	#[inline]
 	pub fn into_slice(self) -> NonNull<[u8]> {
 		self.0
 	}
 
+	#[inline]
 	pub fn size(&self) -> usize {
 		self.0.len()
 	}
@@ -152,6 +155,7 @@ impl<'t> Pages<'t> {
 		self.size() / Self::granularity()
 	}
 
+	#[inline]
 	pub fn is_empty(&self) -> bool {
 		self.size() == 0
 	}
@@ -220,7 +224,7 @@ impl<'t> Pages<'t> {
 	}
 
 	pub fn pages(&'t self, range: Range<usize>) -> Option<Pages<'t>> {
-		if range.start < self.len() && range.end <= self.len() {
+		if likely(range.start < self.len() && range.end <= self.len()) {
 			Some(unsafe {
 				Self::from_ptr(self.as_ptr::<u8>().add(range.start * Self::granularity()),
 				(range.end - range.start - 1) * Self::granularity())
@@ -287,14 +291,17 @@ impl Allocation {
 		self.0.as_ptr().cast::<T>()
 	}
 
+	#[inline]
 	pub fn into_ptr<T>(self) -> *mut T {
 		ManuallyDrop::new(self).as_ptr()
 	}
 
+	#[inline]
 	pub fn into_slice(self) -> NonNull<[u8]> {
 		ManuallyDrop::new(self).0
 	}
 
+	#[inline]
 	pub fn size(&self) -> usize {
 		self.0.len()
 	}
@@ -303,6 +310,7 @@ impl Allocation {
 		self.size() / Pages::granularity()
 	}
 
+	#[inline]
 	pub fn is_empty(&self) -> bool {
 		self.size() == 0
 	}
@@ -364,7 +372,7 @@ impl Allocation {
 	}
 
 	pub fn pages(&self, range: Range<usize>) -> Option<Pages> {
-		if range.start < self.len() && range.end <= self.len() {
+		if likely(range.start < self.len() && range.end <= self.len()) {
 			Some(unsafe {
 				Pages::from_ptr(self.as_ptr::<u8>().add(range.start * Pages::granularity()),
 				(range.end - range.start) * Pages::granularity())
@@ -380,7 +388,7 @@ impl Drop for Allocation {
 		#[cfg(unix)] {
 			use libc::munmap;
 
-			if unsafe { munmap(self.as_ptr::<c_void>(), self.0.len()) } != 0 {
+			if unlikely(unsafe { munmap(self.as_ptr::<c_void>(), self.0.len()) } != 0) {
 				panic!("{}", Error::last_os_error());
 			}
 		}
@@ -389,7 +397,7 @@ impl Drop for Allocation {
 			use winapi::um::memoryapi::VirtualFree;
 			use winapi::um::winnt::MEM_RELEASE;
 
-			if unsafe { VirtualFree(self.as_ptr::<c_void>(), 0, MEM_RELEASE) } == 0 {
+			if unlikely(unsafe { VirtualFree(self.as_ptr::<c_void>(), 0, MEM_RELEASE) } == 0) {
 				panic!("{}", Error::last_os_error());
 			}
 		}
@@ -414,7 +422,7 @@ impl<const N: usize> GuardedAlloc<N> {
 	pub fn new(size: usize, prot: Protection) -> Result<Self, Error> {
 		let alloc = Self(Allocation::new(Self::outer_size(size), Protection::NoAccess)?);
 
-		if !alloc.inner().is_empty() {
+		if likely(!alloc.inner().is_empty()) {
 			alloc.inner().protect(prot)?;
 		}
 
